mix permit_phoenix.install (permit_phoenix v0.5.0)

Copy Markdown View Source

Installs Permit.Phoenix authorization into your project, creating an actions module and patching the web module to include LiveView authorization.

Usage

mix permit_phoenix.install

Options

  • --authorization-module - Authorization module name (default: <MyApp>.Authorization)
  • --actions-module - Actions module name (default: <MyApp>.Authorization.Actions)
  • --router - Phoenix router module (auto-detected if not specified)