Installs Permit.Phoenix authorization into your project, creating an actions module and patching the web module to include LiveView authorization.
Usage
mix permit_phoenix.installOptions
--authorization-module- Authorization module name (default:<MyApp>.Authorization)--actions-module- Actions module name (default:<MyApp>.Authorization.Actions)--router- Phoenix router module (auto-detected if not specified)